
<!--
FrozenIsBool False
-->

#Databasers

##Doc
----


> 
> The Databasers defines the Noders that take the role of 
> the client-side "Model" in the MVC architecture of SYS. 
> Here the databasing process relies on a hdf5 
> pytable wrapping, going from simple encapsulations
> of the create_table,insert methods to 'sophisticated'
> routines that facilitate the joins between tables and 
> the automatic shaping of the rowed datas.
> 
> 
> 

----

<small>
View the Databasers notebook on [NbViewer](http://nbviewer.ipython.org/url/shareyoursystem.ouvaton.org/Databasers.ipynb)
</small>

